<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Löschen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Diashow</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exportieren</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopieren</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Foto-Info</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Video-Info</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Wiederherstellen</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Ohne Namen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Neues Album</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Sind Sie sicher, dass Sie dieses Album löschen möchten?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Papierkorb</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Papierkorb</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Oder ziehen Sie die Fotos hierher</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Alle importieren</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importieren nach:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Systemlaufwerk</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Laufwerk arbeitet, kann jetzt nicht ausgeworfen werden</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Wird geladen ...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>Die Dateien werden nach Ablauf der auf ihnen angegebenen Tage endgültig gelöscht</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Speichern in:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Andere Verzeichnisse auswählen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Dateiname kann nicht leer sein</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>existiert schon. Möchten Sie es ersetzen?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(Kopie)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Laufwerk</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Leeres %1 Laufwerk</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 verschlüsselt</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Laufwerk</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Fotos exportieren</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Wird gelöscht ...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Wird wiederhergestellt ...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>Sind Sie sicher, dass Sie diese Datei endgültig löschen möchen?</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>Sie können sie nicht mehr wiederherstellen</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>Sind Sie sicher, dass sie endgültig %1 Dateien löschen möchten?</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>Sie können sie nicht mehr wiederherstellen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>Sind Sie sicher, dass Sie diese Datei lokal löschen möchten?</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>Sie können Sie im Papierkorb wiederherstellen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>Sind Sie sicher, dass Sie %1 Dateien lokal löschen möchten?</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>Sie können sie im Papierkorb wiederherstellen</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Allgemeine Informationen</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinfo</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 Foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 Video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n Fotos</numerusform>
            <numerusform>%n Fotos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n Videos</numerusform>
            <numerusform>%n Videos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n Objekte</numerusform>
            <numerusform>%n Objekte</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Fotos und Videos importieren</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>Oder hierher ziehen</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Alle Fotos und Videos</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Keine Fotos oder Videos gefunden</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Alben</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Album ist ein trendiger Fotomanager zum Betrachten und Organisieren von Bildern.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Aus Favoriten entfernen</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Album umbenennen</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Album &quot;%1&quot; gelöscht</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Erfolgreich zu &quot;%1&quot; hinzugefügt</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importieren erfolgreich</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Importieren fehlgeschlagen</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Exportieren fehlgeschlagen</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Exportieren erfolgreich</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Alle Fotos</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Zeitleisten</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Alben</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Vollbildmodus/Diashow verlassen</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkombinationen anzeigen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Alle auswählen</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Hineinzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Herauszoomen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Bild auf</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Bild ab</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Wird importiert ...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Alle Fotos und Videos</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Fotos und Videos importieren</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Keine Fotos oder Videos gefunden</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Fotos exportieren</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Fotos/Videos importieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Foto-/Videoinfo</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>Fotos und Videos importieren</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>Ordner importieren</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>Import unterbrochen</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>Der Pfad kann nicht hinzugefügt werden. Bitte versuchen Sie einen anderen</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>Der Pfad existiert bereits</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>%1 Dateien konnten nicht wiederhergestellt werden: Dateiname zu lang</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Blitz</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Abmessungen</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Aufnahmedatum</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Änderungsdatum</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtungsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtunsprogramm</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtungszeit</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Blende</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brennweite</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maximale Blende</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Messmodus</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Weißabgleich</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blitzbelichtungskorrektur</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramodell</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Objektivmodell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Farbraum</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Keine Ergebnisse</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Systemlaufwerk</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Abwählen</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importiert am</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Importiert von</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alle auswählen</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Alle abwählen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotos</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Keine Ergebnisse</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Wird importiert ...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 Elemente importiert</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 Elemente gelöscht</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 Elemente importiert, %2 Elemente fehlgeschlagen</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 Foto ausgewählt</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 Video ausgewählt</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>Das Foto/Video existiert bereits</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>%n Fotos ausgewählt</numerusform>
            <numerusform>%n Fotos ausgewählt</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>%n Videos ausgewählt</numerusform>
            <numerusform>%n Videos ausgewählt</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>%n Objekte ausgewählt</numerusform>
            <numerusform>%n Objekte ausgewählt</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 Elemente importiert, %2 Elemente existieren bereits</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Suchergebnisse</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>1 Foto gefunden</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>%n Videos gefunden</numerusform>
            <numerusform>%n Videos gefunden</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>1 Video gefunden</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>%n Objekte gefunden</numerusform>
            <numerusform>%n Objekte gefunden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>%n Fotos gefunden</numerusform>
            <numerusform>%n Fotos gefunden</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 Foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 Video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n Fotos</numerusform>
            <numerusform>%n Fotos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n Videos</numerusform>
            <numerusform>%n Videos</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Wird importiert: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Wird exportiert: %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Aus Favoriten entfernen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Foto-Info</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Zum Album hinzufügen</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video-Info</translation>
    </message>
    <message>
        <source>days</source>
        <translation>Tage</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 Foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 Video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n Fotos</numerusform>
            <numerusform>%n Fotos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n Videos</numerusform>
            <numerusform>%n Videos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n Objekte</numerusform>
            <numerusform>%n Objekte</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Allgemeine Informationen</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Codec-Info</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Audio-Info</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Videocodec-ID</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Video-Codierungsrate</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>BpS</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Verhältnis</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Auflösung</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Audiocodec-ID</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Audio-Codierungsrate</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Abtastung</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Änderungsdatum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Pfad</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Video-Info</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Aufnahmedatum</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
</TS>
